@@ -719,53 +719,6 @@ class DirectEnhanceByStampSheetResult(core.Gs2Result):
         }
 
 
-class DescribeProgressesByUserIdResult(core.Gs2Result):
-    items: List[Progress] = None
-    next_page_token: str = None
-
-    def with_items(self, items: List[Progress]) -> DescribeProgressesByUserIdResult:
-        self.items = items
-        return self
-
-    def with_next_page_token(self, next_page_token: str) -> DescribeProgressesByUserIdResult:
-        self.next_page_token = next_page_token
-        return self
-
-    def get(self, key, default=None):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return default
-
-    def __getitem__(self, key):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return None
-
-    @staticmethod
-    def from_dict(
-        data: Dict[str, Any],
-    ) -> Optional[DescribeProgressesByUserIdResult]:
-        if data is None:
-            return None
-        return DescribeProgressesByUserIdResult()\
-            .with_items([
-                Progress.from_dict(data.get('items')[i])
-                for i in range(len(data.get('items')) if data.get('items') else 0)
-            ])\
-            .with_next_page_token(data.get('nextPageToken'))
-
-    def to_dict(self) -> Dict[str, Any]:
-        return {
-            "items": [
-                self.items[i].to_dict() if self.items[i] else None
-                for i in range(len(self.items) if self.items else 0)
-            ],
-            "nextPageToken": self.next_page_token,
-        }
-
-
 class CreateProgressByUserIdResult(core.Gs2Result):
     item: Progress = None
 
@@ -802,16 +755,11 @@ class CreateProgressByUserIdResult(core.Gs2Result):
 
 class GetProgressResult(core.Gs2Result):
     item: Progress = None
-    rate_model: RateModel = None
 
     def with_item(self, item: Progress) -> GetProgressResult:
         self.item = item
         return self
 
-    def with_rate_model(self, rate_model: RateModel) -> GetProgressResult:
-        self.rate_model = rate_model
-        return self
-
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -831,28 +779,21 @@ class GetProgressResult(core.Gs2Result):
         if data is None:
             return None
         return GetProgressResult()\
-            .with_item(Progress.from_dict(data.get('item')))\
-            .with_rate_model(RateModel.from_dict(data.get('rateModel')))
+            .with_item(Progress.from_dict(data.get('item')))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "item": self.item.to_dict() if self.item else None,
-            "rateModel": self.rate_model.to_dict() if self.rate_model else None,
         }
 
 
 class GetProgressByUserIdResult(core.Gs2Result):
     item: Progress = None
-    rate_model: RateModel = None
 
     def with_item(self, item: Progress) -> GetProgressByUserIdResult:
         self.item = item
         return self
 
-    def with_rate_model(self, rate_model: RateModel) -> GetProgressByUserIdResult:
-        self.rate_model = rate_model
-        return self
-
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -872,13 +813,11 @@ class GetProgressByUserIdResult(core.Gs2Result):
         if data is None:
             return None
         return GetProgressByUserIdResult()\
-            .with_item(Progress.from_dict(data.get('item')))\
-            .with_rate_model(RateModel.from_dict(data.get('rateModel')))
+            .with_item(Progress.from_dict(data.get('item')))
 
     def to_dict(self) -> Dict[str, Any]:
         return {
             "item": self.item.to_dict() if self.item else None,
-            "rateModel": self.rate_model.to_dict() if self.rate_model else None,
         }
 
 
