@@ -378,6 +378,7 @@ class QueryAccessLogRequest(core.Gs2Request):
     long_term: bool = None
     page_token: str = None
     limit: int = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> QueryAccessLogRequest:
         self.namespace_name = namespace_name
@@ -415,6 +416,10 @@ class QueryAccessLogRequest(core.Gs2Request):
         self.limit = limit
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> QueryAccessLogRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -563,6 +568,7 @@ class QueryIssueStampSheetLogRequest(core.Gs2Request):
     long_term: bool = None
     page_token: str = None
     limit: int = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> QueryIssueStampSheetLogRequest:
         self.namespace_name = namespace_name
@@ -604,6 +610,10 @@ class QueryIssueStampSheetLogRequest(core.Gs2Request):
         self.limit = limit
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> QueryIssueStampSheetLogRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -761,6 +771,7 @@ class QueryExecuteStampSheetLogRequest(core.Gs2Request):
     long_term: bool = None
     page_token: str = None
     limit: int = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> QueryExecuteStampSheetLogRequest:
         self.namespace_name = namespace_name
@@ -802,6 +813,10 @@ class QueryExecuteStampSheetLogRequest(core.Gs2Request):
         self.limit = limit
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> QueryExecuteStampSheetLogRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -959,6 +974,7 @@ class QueryExecuteStampTaskLogRequest(core.Gs2Request):
     long_term: bool = None
     page_token: str = None
     limit: int = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> QueryExecuteStampTaskLogRequest:
         self.namespace_name = namespace_name
@@ -1000,6 +1016,10 @@ class QueryExecuteStampTaskLogRequest(core.Gs2Request):
         self.limit = limit
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> QueryExecuteStampTaskLogRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
