@@ -1011,167 +1011,6 @@ class LotteryModel(core.Gs2Model):
         }
 
 
-class Box(core.Gs2Model):
-    box_id: str = None
-    prize_table_name: str = None
-    index: int = None
-    user_id: str = None
-    drawn_indexes: List[int] = None
-    created_at: int = None
-    updated_at: int = None
-
-    def with_box_id(self, box_id: str) -> Box:
-        self.box_id = box_id
-        return self
-
-    def with_prize_table_name(self, prize_table_name: str) -> Box:
-        self.prize_table_name = prize_table_name
-        return self
-
-    def with_index(self, index: int) -> Box:
-        self.index = index
-        return self
-
-    def with_user_id(self, user_id: str) -> Box:
-        self.user_id = user_id
-        return self
-
-    def with_drawn_indexes(self, drawn_indexes: List[int]) -> Box:
-        self.drawn_indexes = drawn_indexes
-        return self
-
-    def with_created_at(self, created_at: int) -> Box:
-        self.created_at = created_at
-        return self
-
-    def with_updated_at(self, updated_at: int) -> Box:
-        self.updated_at = updated_at
-        return self
-
-    @classmethod
-    def create_grn(
-        cls,
-        region,
-        owner_id,
-        namespace_name,
-        user_id,
-        prize_table_name,
-        index,
-    ):
-        return 'grn:gs2:{region}:{ownerId}:lottery:{namespaceName}:user:{userId}:box:table:{prizeTableName}:{index}'.format(
-            region=region,
-            ownerId=owner_id,
-            namespaceName=namespace_name,
-            userId=user_id,
-            prizeTableName=prize_table_name,
-            index=index,
-        )
-
-    @classmethod
-    def get_region_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):lottery:(?P<namespaceName>.+):user:(?P<userId>.+):box:table:(?P<prizeTableName>.+):(?P<index>.+)', grn)
-        if match is None:
-            return None
-        return match.group('region')
-
-    @classmethod
-    def get_owner_id_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):lottery:(?P<namespaceName>.+):user:(?P<userId>.+):box:table:(?P<prizeTableName>.+):(?P<index>.+)', grn)
-        if match is None:
-            return None
-        return match.group('owner_id')
-
-    @classmethod
-    def get_namespace_name_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):lottery:(?P<namespaceName>.+):user:(?P<userId>.+):box:table:(?P<prizeTableName>.+):(?P<index>.+)', grn)
-        if match is None:
-            return None
-        return match.group('namespace_name')
-
-    @classmethod
-    def get_user_id_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):lottery:(?P<namespaceName>.+):user:(?P<userId>.+):box:table:(?P<prizeTableName>.+):(?P<index>.+)', grn)
-        if match is None:
-            return None
-        return match.group('user_id')
-
-    @classmethod
-    def get_prize_table_name_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):lottery:(?P<namespaceName>.+):user:(?P<userId>.+):box:table:(?P<prizeTableName>.+):(?P<index>.+)', grn)
-        if match is None:
-            return None
-        return match.group('prize_table_name')
-
-    @classmethod
-    def get_index_from_grn(
-        cls,
-        grn: str,
-    ) -> Optional[str]:
-        match = re.search('grn:gs2:(?P<region>.+):(?P<ownerId>.+):lottery:(?P<namespaceName>.+):user:(?P<userId>.+):box:table:(?P<prizeTableName>.+):(?P<index>.+)', grn)
-        if match is None:
-            return None
-        return match.group('index')
-
-    def get(self, key, default=None):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return default
-
-    def __getitem__(self, key):
-        items = self.to_dict()
-        if key in items.keys():
-            return items[key]
-        return None
-
-    @staticmethod
-    def from_dict(
-        data: Dict[str, Any],
-    ) -> Optional[Box]:
-        if data is None:
-            return None
-        return Box()\
-            .with_box_id(data.get('boxId'))\
-            .with_prize_table_name(data.get('prizeTableName'))\
-            .with_index(data.get('index'))\
-            .with_user_id(data.get('userId'))\
-            .with_drawn_indexes([
-                data.get('drawnIndexes')[i]
-                for i in range(len(data.get('drawnIndexes')) if data.get('drawnIndexes') else 0)
-            ])\
-            .with_created_at(data.get('createdAt'))\
-            .with_updated_at(data.get('updatedAt'))
-
-    def to_dict(self) -> Dict[str, Any]:
-        return {
-            "boxId": self.box_id,
-            "prizeTableName": self.prize_table_name,
-            "index": self.index,
-            "userId": self.user_id,
-            "drawnIndexes": [
-                self.drawn_indexes[i]
-                for i in range(len(self.drawn_indexes) if self.drawn_indexes else 0)
-            ],
-            "createdAt": self.created_at,
-            "updatedAt": self.updated_at,
-        }
-
-
 class PrizeTableMaster(core.Gs2Model):
     prize_table_id: str = None
     name: str = None
