@@ -72,6 +72,7 @@ class CreateNamespaceRequest(core.Gs2Request):
     complete_matchmaking_trigger_type: str = None
     complete_matchmaking_trigger_realtime_namespace_id: str = None
     complete_matchmaking_trigger_script_id: str = None
+    change_rating_script: ScriptSetting = None
     join_notification: NotificationSetting = None
     leave_notification: NotificationSetting = None
     complete_notification: NotificationSetting = None
@@ -113,6 +114,10 @@ class CreateNamespaceRequest(core.Gs2Request):
         self.complete_matchmaking_trigger_script_id = complete_matchmaking_trigger_script_id
         return self
 
+    def with_change_rating_script(self, change_rating_script: ScriptSetting) -> CreateNamespaceRequest:
+        self.change_rating_script = change_rating_script
+        return self
+
     def with_join_notification(self, join_notification: NotificationSetting) -> CreateNamespaceRequest:
         self.join_notification = join_notification
         return self
@@ -157,6 +162,7 @@ class CreateNamespaceRequest(core.Gs2Request):
             .with_complete_matchmaking_trigger_type(data.get('completeMatchmakingTriggerType'))\
             .with_complete_matchmaking_trigger_realtime_namespace_id(data.get('completeMatchmakingTriggerRealtimeNamespaceId'))\
             .with_complete_matchmaking_trigger_script_id(data.get('completeMatchmakingTriggerScriptId'))\
+            .with_change_rating_script(ScriptSetting.from_dict(data.get('changeRatingScript')))\
             .with_join_notification(NotificationSetting.from_dict(data.get('joinNotification')))\
             .with_leave_notification(NotificationSetting.from_dict(data.get('leaveNotification')))\
             .with_complete_notification(NotificationSetting.from_dict(data.get('completeNotification')))\
@@ -173,6 +179,7 @@ class CreateNamespaceRequest(core.Gs2Request):
             "completeMatchmakingTriggerType": self.complete_matchmaking_trigger_type,
             "completeMatchmakingTriggerRealtimeNamespaceId": self.complete_matchmaking_trigger_realtime_namespace_id,
             "completeMatchmakingTriggerScriptId": self.complete_matchmaking_trigger_script_id,
+            "changeRatingScript": self.change_rating_script.to_dict() if self.change_rating_script else None,
             "joinNotification": self.join_notification.to_dict() if self.join_notification else None,
             "leaveNotification": self.leave_notification.to_dict() if self.leave_notification else None,
             "completeNotification": self.complete_notification.to_dict() if self.complete_notification else None,
@@ -264,6 +271,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
     complete_matchmaking_trigger_type: str = None
     complete_matchmaking_trigger_realtime_namespace_id: str = None
     complete_matchmaking_trigger_script_id: str = None
+    change_rating_script: ScriptSetting = None
     join_notification: NotificationSetting = None
     leave_notification: NotificationSetting = None
     complete_notification: NotificationSetting = None
@@ -305,6 +313,10 @@ class UpdateNamespaceRequest(core.Gs2Request):
         self.complete_matchmaking_trigger_script_id = complete_matchmaking_trigger_script_id
         return self
 
+    def with_change_rating_script(self, change_rating_script: ScriptSetting) -> UpdateNamespaceRequest:
+        self.change_rating_script = change_rating_script
+        return self
+
     def with_join_notification(self, join_notification: NotificationSetting) -> UpdateNamespaceRequest:
         self.join_notification = join_notification
         return self
@@ -349,6 +361,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
             .with_complete_matchmaking_trigger_type(data.get('completeMatchmakingTriggerType'))\
             .with_complete_matchmaking_trigger_realtime_namespace_id(data.get('completeMatchmakingTriggerRealtimeNamespaceId'))\
             .with_complete_matchmaking_trigger_script_id(data.get('completeMatchmakingTriggerScriptId'))\
+            .with_change_rating_script(ScriptSetting.from_dict(data.get('changeRatingScript')))\
             .with_join_notification(NotificationSetting.from_dict(data.get('joinNotification')))\
             .with_leave_notification(NotificationSetting.from_dict(data.get('leaveNotification')))\
             .with_complete_notification(NotificationSetting.from_dict(data.get('completeNotification')))\
@@ -365,6 +378,7 @@ class UpdateNamespaceRequest(core.Gs2Request):
             "completeMatchmakingTriggerType": self.complete_matchmaking_trigger_type,
             "completeMatchmakingTriggerRealtimeNamespaceId": self.complete_matchmaking_trigger_realtime_namespace_id,
             "completeMatchmakingTriggerScriptId": self.complete_matchmaking_trigger_script_id,
+            "changeRatingScript": self.change_rating_script.to_dict() if self.change_rating_script else None,
             "joinNotification": self.join_notification.to_dict() if self.join_notification else None,
             "leaveNotification": self.leave_notification.to_dict() if self.leave_notification else None,
             "completeNotification": self.complete_notification.to_dict() if self.complete_notification else None,
@@ -469,7 +483,7 @@ class CreateGatheringRequest(core.Gs2Request):
     allow_user_ids: List[str] = None
     expires_at: int = None
     expires_at_time_span: TimeSpan = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> CreateGatheringRequest:
         self.namespace_name = namespace_name
@@ -503,6 +517,10 @@ class CreateGatheringRequest(core.Gs2Request):
         self.expires_at_time_span = expires_at_time_span
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> CreateGatheringRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -677,7 +695,7 @@ class UpdateGatheringRequest(core.Gs2Request):
     gathering_name: str = None
     access_token: str = None
     attribute_ranges: List[AttributeRange] = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> UpdateGatheringRequest:
         self.namespace_name = namespace_name
@@ -695,6 +713,10 @@ class UpdateGatheringRequest(core.Gs2Request):
         self.attribute_ranges = attribute_ranges
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> UpdateGatheringRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -859,7 +881,7 @@ class DoMatchmakingRequest(core.Gs2Request):
     access_token: str = None
     player: Player = None
     matchmaking_context_token: str = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DoMatchmakingRequest:
         self.namespace_name = namespace_name
@@ -877,6 +899,10 @@ class DoMatchmakingRequest(core.Gs2Request):
         self.matchmaking_context_token = matchmaking_context_token
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> DoMatchmakingRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1021,7 +1047,7 @@ class CancelMatchmakingRequest(core.Gs2Request):
     namespace_name: str = None
     gathering_name: str = None
     access_token: str = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> CancelMatchmakingRequest:
         self.namespace_name = namespace_name
@@ -1035,6 +1061,10 @@ class CancelMatchmakingRequest(core.Gs2Request):
         self.access_token = access_token
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> CancelMatchmakingRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1672,7 +1702,6 @@ class DescribeRatingsRequest(core.Gs2Request):
     access_token: str = None
     page_token: str = None
     limit: int = None
-    access_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DescribeRatingsRequest:
         self.namespace_name = namespace_name
@@ -1786,7 +1815,6 @@ class GetRatingRequest(core.Gs2Request):
     namespace_name: str = None
     access_token: str = None
     rating_name: str = None
-    access_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> GetRatingRequest:
         self.namespace_name = namespace_name
@@ -2001,7 +2029,6 @@ class GetBallotRequest(core.Gs2Request):
     access_token: str = None
     number_of_player: int = None
     key_id: str = None
-    access_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> GetBallotRequest:
         self.namespace_name = namespace_name
