@@ -1355,7 +1355,6 @@ class DescribeShowcasesRequest(core.Gs2Request):
     context_stack: str = None
     namespace_name: str = None
     access_token: str = None
-    access_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> DescribeShowcasesRequest:
         self.namespace_name = namespace_name
@@ -1443,7 +1442,6 @@ class GetShowcaseRequest(core.Gs2Request):
     namespace_name: str = None
     showcase_name: str = None
     access_token: str = None
-    access_token: str = None
 
     def with_namespace_name(self, namespace_name: str) -> GetShowcaseRequest:
         self.namespace_name = namespace_name
@@ -1547,7 +1545,7 @@ class BuyRequest(core.Gs2Request):
     access_token: str = None
     quantity: int = None
     config: List[Config] = None
-    access_token: str = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> BuyRequest:
         self.namespace_name = namespace_name
@@ -1573,6 +1571,10 @@ class BuyRequest(core.Gs2Request):
         self.config = config
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> BuyRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
@@ -1625,6 +1627,7 @@ class BuyByUserIdRequest(core.Gs2Request):
     user_id: str = None
     quantity: int = None
     config: List[Config] = None
+    duplication_avoider: str = None
 
     def with_namespace_name(self, namespace_name: str) -> BuyByUserIdRequest:
         self.namespace_name = namespace_name
@@ -1650,6 +1653,10 @@ class BuyByUserIdRequest(core.Gs2Request):
         self.config = config
         return self
 
+    def with_duplication_avoider(self, duplication_avoider: str) -> BuyByUserIdRequest:
+        self.duplication_avoider = duplication_avoider
+        return self
+
     def get(self, key, default=None):
         items = self.to_dict()
         if key in items.keys():
